/**
 * Copyright (c) 2014, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * https://raw.github.com/facebook/regenerator/master/LICENSE file. An
 * additional grant of patent rights can be found in the PATENTS file in
 * the same directory.
 */

!(function(global) {
  "use strict";

  var hasOwn = Object.prototype.hasOwnProperty;
  var undefined; // More compressible than void 0.
  var $Symbol = typeof Symbol === "function" ? Symbol : {};
  var iteratorSymbol = $Symbol.iterator || "@@iterator";
  var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

  var inModule = typeof module === "object";
  var runtime = global.regeneratorRuntime;
  if (runtime) {
    if (inModule) {
      // If regeneratorRuntime is defined globally and we're in a module,
      // make the exports object identical to regeneratorRuntime.
      module.exports = runtime;
    }
    // Don't bother evaluating the rest of this file if the runtime was
    // already defined globally.
    return;
  }

  // Define the runtime globally (as expected by generated code) as either
  // module.exports (if we're in a module) or a new, empty object.
  runtime = global.regeneratorRuntime = inModule ? module.exports : {};

  function wrap(innerFn, outerFn, self, tryLocsList) {
    // If outerFn provided, then outerFn.prototype instanceof Generator.
    var generator = Object.create((outerFn || Generator).prototype);
    var context = new Context(tryLocsList || []);

    // The ._invoke method unifies the implementations of the .next,
    // .throw, and .return methods.
    generator._invoke = makeInvokeMethod(innerFn, self, context);

    return generator;
  }
  runtime.wrap = wrap;

  // Try/catch helper to minimize deoptimizations. Returns a completion
  // record like context.tryEntries[i].completion. This interface could
  // have been (and was previously) designed to take a closure to be
  // invoked without arguments, but in all the cases we care about we
  // already have an existing method we want to call, so there's no need
  // to create a new function object. We can even get away with assuming
  // the method takes exactly one argument, since that happens to be true
  // in every case, so we don't have to touch the arguments object. The
  // only additional allocation required is the completion record, which
  // has a stable shape and so hopefully should be cheap to allocate.
  function tryCatch(fn, obj, arg) {
    try {
      return { type: "normal", arg: fn.call(obj, arg) };
    } catch (err) {
      return { type: "throw", arg: err };
    }
  }

  var GenStateSuspendedStart = "suspendedStart";
  var GenStateSuspendedYield = "suspendedYield";
  var GenStateExecuting = "executing";
  var GenStateCompleted = "completed";

  // Returning this object from the innerFn has the same effect as
  // breaking out of the dispatch switch statement.
  var ContinueSentinel = {};

  // Dummy constructor functions that we use as the .constructor and
  // .constructor.prototype properties for functions that return Generator
  // objects. For full spec compliance, you may wish to configure your
  // minifier not to mangle the names of these two functions.
  function Generator() {}
  function GeneratorFunction() {}
  function GeneratorFunctionPrototype() {}

  var Gp = GeneratorFunctionPrototype.prototype = Generator.prototype;
  GeneratorFunction.prototype = Gp.constructor = GeneratorFunctionPrototype;
  GeneratorFunctionPrototype.constructor = GeneratorFunction;
  GeneratorFunctionPrototype[toStringTagSymbol] = GeneratorFunction.displayName = "GeneratorFunction";

  // Helper for defining the .next, .throw, and .return methods of the
  // Iterator interface in terms of a single ._invoke method.
  function defineIteratorMethods(prototype) {
    ["next", "throw", "return"].forEach(function(method) {
      prototype[method] = function(arg) {
        return this._invoke(method, arg);
      };
    });
  }

  runtime.isGeneratorFunction = function(genFun) {
    var ctor = typeof genFun === "function" && genFun.constructor;
    return ctor
      ? ctor === GeneratorFunction ||
        // For the native GeneratorFunction constructor, the best we can
        // do is to check its .name property.
        (ctor.displayName || ctor.name) === "GeneratorFunction"
      : false;
  };

  runtime.mark = function(genFun) {
    if (Object.setPrototypeOf) {
      Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
    } else {
      genFun.__proto__ = GeneratorFunctionPrototype;
      if (!(toStringTagSymbol in genFun)) {
        genFun[toStringTagSymbol] = "GeneratorFunction";
      }
    }
    genFun.prototype = Object.create(Gp);
    return genFun;
  };

  // Within the body of any async function, `await x` is transformed to
  // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
  // `value instanceof AwaitArgument` to determine if the yielded value is
  // meant to be awaited. Some may consider the name of this method too
  // cutesy, but they are curmudgeons.
  runtime.awrap = function(arg) {
    return new AwaitArgument(arg);
  };

  function AwaitArgument(arg) {
    this.arg = arg;
  }

  function AsyncIterator(generator) {
    function invoke(method, arg, resolve, reject) {
      var record = tryCatch(generator[method], generator, arg);
      if (record.type === "throw") {
        reject(record.arg);
      } else {
        var result = record.arg;
        var value = result.value;
        if (value instanceof AwaitArgument) {
          return Promise.resolve(value.arg).then(function(value) {
            invoke("next", value, resolve, reject);
          }, function(err) {
            invoke("throw", err, resolve, reject);
          });
        }

        return Promise.resolve(value).then(function(unwrapped) {
          // When a yielded Promise is resolved, its final value becomes
          // the .value of the Promise<{value,done}> result for the
          // current iteration. If the Promise is rejected, however, the
          // result for this iteration will be rejected with the same
          // reason. Note that rejections of yielded Promises are not
          // thrown back into the generator function, as is the case
          // when an awaited Promise is rejected. This difference in
          // behavior between yield and await is important, because it
          // allows the consumer to decide what to do with the yielded
          // rejection (swallow it and continue, manually .throw it back
          // into the generator, abandon iteration, whatever). With
          // await, by contrast, there is no opportunity to examine the
          // rejection reason outside the generator function, so the
          // only option is to throw it from the await expression, and
          // let the generator function handle the exception.
          result.value = unwrapped;
          resolve(result);
        }, reject);
      }
    }

    if (typeof process === "object" && process.domain) {
      invoke = process.domain.bind(invoke);
    }

    var previousPromise;

    function enqueue(method, arg) {
      function callInvokeWithMethodAndArg() {
        return new Promise(function(resolve, reject) {
          invoke(method, arg, resolve, reject);
        });
      }

      return previousPromise =
        // If enqueue has been called before, then we want to wait until
        // all previous Promises have been resolved before calling invoke,
        // so that results are always delivered in the correct order. If
        // enqueue has not been called before, then it is important to
        // call invoke immediately, without waiting on a callback to fire,
        // so that the async generator function has the opportunity to do
        // any necessary setup in a predictable way. This predictability
        // is why the Promise constructor synchronously invokes its
        // executor callback, and why async functions synchronously
        // execute code before the first await. Since we implement simple
        // async functions in terms of async generators, it is especially
        // important to get this right, even though it requires care.
        previousPromise ? previousPromise.then(
          callInvokeWithMethodAndArg,
          // Avoid propagating failures to Promises returned by later
          // invocations of the iterator.
          callInvokeWithMethodAndArg
        ) : callInvokeWithMethodAndArg();
    }

    // Define the unified helper method that is used to implement .next,
    // .throw, and .return (see defineIteratorMethods).
    this._invoke = enqueue;
  }

  defineIteratorMethods(AsyncIterator.prototype);

  // Note that simple async functions are implemented on top of
  // AsyncIterator objects; they just return a Promise for the value of
  // the final result produced by the iterator.
  runtime.async = function(innerFn, outerFn, self, tryLocsList) {
    var iter = new AsyncIterator(
      wrap(innerFn, outerFn, self, tryLocsList)
    );

    return runtime.isGeneratorFunction(outerFn)
      ? iter // If outerFn is a generator, return the full iterator.
      : iter.next().then(function(result) {
          return result.done ? result.value : iter.next();
        });
  };

  function makeInvokeMethod(innerFn, self, context) {
    var state = GenStateSuspendedStart;

    return function invoke(method, arg) {
      if (state === GenStateExecuting) {
        throw new Error("Generator is already running");
      }

      if (state === GenStateCompleted) {
        if (method === "throw") {
          throw arg;
        }

        // Be forgiving, per 25.3.3.3.3 of the spec:
        // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
        return doneResult();
      }

      while (true) {
        var delegate = context.delegate;
        if (delegate) {
          if (method === "return" ||
              (method === "throw" && delegate.iterator[method] === undefined)) {
            // A return or throw (when the delegate iterator has no throw
            // method) always terminates the yield* loop.
            context.delegate = null;

            // If the delegate iterator has a return method, give it a
            // chance to clean up.
            var returnMethod = delegate.iterator["return"];
            if (returnMethod) {
              var record = tryCatch(returnMethod, delegate.iterator, arg);
              if (record.type === "throw") {
                // If the return method threw an exception, let that
                // exception prevail over the original return or throw.
                method = "throw";
                arg = record.arg;
                continue;
              }
            }

            if (method === "return") {
              // Continue with the outer return, now that the delegate
              // iterator has been terminated.
              continue;
            }
          }

          var record = tryCatch(
            delegate.iterator[method],
            delegate.iterator,
            arg
          );

          if (record.type === "throw") {
            context.delegate = null;

            // Like returning generator.throw(uncaught), but without the
            // overhead of an extra function call.
            method = "throw";
            arg = record.arg;
            continue;
          }

          // Delegate generator ran and handled its own exceptions so
          // regardless of what the method was, we continue as if it is
          // "next" with an undefined arg.
          method = "next";
          arg = undefined;

          var info = record.arg;
          if (info.done) {
            context[delegate.resultName] = info.value;
            context.next = delegate.nextLoc;
          } else {
            state = GenStateSuspendedYield;
            return info;
          }

          context.delegate = null;
        }

        if (method === "next") {
          // Setting context._sent for legacy support of Babel's
          // function.sent implementation.
          context.sent = context._sent = arg;

        } else if (method === "throw") {
          if (state === GenStateSuspendedStart) {
            state = GenStateCompleted;
            throw arg;
          }

          if (context.dispatchException(arg)) {
            // If the dispatched exception was caught by a catch block,
            // then let that catch block handle the exception normally.
            method = "next";
            arg = undefined;
          }

        } else if (method === "return") {
          context.abrupt("return", arg);
        }

        state = GenStateExecuting;

        var record = tryCatch(innerFn, self, context);
        if (record.type === "normal") {
          // If an exception is thrown from innerFn, we leave state ===
          // GenStateExecuting and loop back for another invocation.
          state = context.done
            ? GenStateCompleted
            : GenStateSuspendedYield;

          var info = {
            value: record.arg,
            done: context.done
          };

          if (record.arg === ContinueSentinel) {
            if (context.delegate && method === "next") {
              // Deliberately forget the last sent value so that we don't
              // accidentally pass it on to the delegate.
              arg = undefined;
            }
          } else {
            return info;
          }

        } else if (record.type === "throw") {
          state = GenStateCompleted;
          // Dispatch the exception by looping back around to the
          // context.dispatchException(arg) call above.
          method = "throw";
          arg = record.arg;
        }
      }
    };
  }

  // Define Generator.prototype.{next,throw,return} in terms of the
  // unified ._invoke helper method.
  defineIteratorMethods(Gp);

  Gp[iteratorSymbol] = function() {
    return this;
  };

  Gp[toStringTagSymbol] = "Generator";

  Gp.toString = function() {
    return "[object Generator]";
  };

  function pushTryEntry(locs) {
    var entry = { tryLoc: locs[0] };

    if (1 in locs) {
      entry.catchLoc = locs[1];
    }

    if (2 in locs) {
      entry.finallyLoc = locs[2];
      entry.afterLoc = locs[3];
    }

    this.tryEntries.push(entry);
  }

  function resetTryEntry(entry) {
    var record = entry.completion || {};
    record.type = "normal";
    delete record.arg;
    entry.completion = record;
  }

  function Context(tryLocsList) {
    // The root entry object (effectively a try statement without a catch
    // or a finally block) gives us a place to store values thrown from
    // locations where there is no enclosing try statement.
    this.tryEntries = [{ tryLoc: "root" }];
    tryLocsList.forEach(pushTryEntry, this);
    this.reset(true);
  }

  runtime.keys = function(object) {
    var keys = [];
    for (var key in object) {
      keys.push(key);
    }
    keys.reverse();

    // Rather than returning an object with a next method, we keep
    // things simple and return the next function itself.
    return function next() {
      while (keys.length) {
        var key = keys.pop();
        if (key in object) {
          next.value = key;
          next.done = false;
          return next;
        }
      }

      // To avoid creating an additional object, we just hang the .value
      // and .done properties off the next function object itself. This
      // also ensures that the minifier will not anonymize the function.
      next.done = true;
      return next;
    };
  };

  function values(iterable) {
    if (iterable) {
      var iteratorMethod = iterable[iteratorSymbol];
      if (iteratorMethod) {
        return iteratorMethod.call(iterable);
      }

      if (typeof iterable.next === "function") {
        return iterable;
      }

      if (!isNaN(iterable.length)) {
        var i = -1, next = function next() {
          while (++i < iterable.length) {
            if (hasOwn.call(iterable, i)) {
              next.value = iterable[i];
              next.done = false;
              return next;
            }
          }

          next.value = undefined;
          next.done = true;

          return next;
        };

        return next.next = next;
      }
    }

    // Return an iterator with no values.
    return { next: doneResult };
  }
  runtime.values = values;

  function doneResult() {
    return { value: undefined, done: true };
  }

  Context.prototype = {
    constructor: Context,

    reset: function(skipTempReset) {
      this.prev = 0;
      this.next = 0;
      // Resetting context._sent for legacy support of Babel's
      // function.sent implementation.
      this.sent = this._sent = undefined;
      this.done = false;
      this.delegate = null;

      this.tryEntries.forEach(resetTryEntry);

      if (!skipTempReset) {
        for (var name in this) {
          // Not sure about the optimal order of these conditions:
          if (name.charAt(0) === "t" &&
              hasOwn.call(this, name) &&
              !isNaN(+name.slice(1))) {
            this[name] = undefined;
          }
        }
      }
    },

    stop: function() {
      this.done = true;

      var rootEntry = this.tryEntries[0];
      var rootRecord = rootEntry.completion;
      if (rootRecord.type === "throw") {
        throw rootRecord.arg;
      }

      return this.rval;
    },

    dispatchException: function(exception) {
      if (this.done) {
        throw exception;
      }

      var context = this;
      function handle(loc, caught) {
        record.type = "throw";
        record.arg = exception;
        context.next = loc;
        return !!caught;
      }

      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        var record = entry.completion;

        if (entry.tryLoc === "root") {
          // Exception thrown outside of any try block that could handle
          // it, so set the completion value of the entire function to
          // throw the exception.
          return handle("end");
        }

        if (entry.tryLoc <= this.prev) {
          var hasCatch = hasOwn.call(entry, "catchLoc");
          var hasFinally = hasOwn.call(entry, "finallyLoc");

          if (hasCatch && hasFinally) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            } else if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else if (hasCatch) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            }

          } else if (hasFinally) {
            if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else {
            throw new Error("try statement without catch or finally");
          }
        }
      }
    },

    abrupt: function(type, arg) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc <= this.prev &&
            hasOwn.call(entry, "finallyLoc") &&
            this.prev < entry.finallyLoc) {
          var finallyEntry = entry;
          break;
        }
      }

      if (finallyEntry &&
          (type === "break" ||
           type === "continue") &&
          finallyEntry.tryLoc <= arg &&
          arg <= finallyEntry.finallyLoc) {
        // Ignore the finally entry if control is not jumping to a
        // location outside the try/catch block.
        finallyEntry = null;
      }

      var record = finallyEntry ? finallyEntry.completion : {};
      record.type = type;
      record.arg = arg;

      if (finallyEntry) {
        this.next = finallyEntry.finallyLoc;
      } else {
        this.complete(record);
      }

      return ContinueSentinel;
    },

    complete: function(record, afterLoc) {
      if (record.type === "throw") {
        throw record.arg;
      }

      if (record.type === "break" ||
          record.type === "continue") {
        this.next = record.arg;
      } else if (record.type === "return") {
        this.rval = record.arg;
        this.next = "end";
      } else if (record.type === "normal" && afterLoc) {
        this.next = afterLoc;
      }
    },

    finish: function(finallyLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.finallyLoc === finallyLoc) {
          this.complete(entry.completion, entry.afterLoc);
          resetTryEntry(entry);
          return ContinueSentinel;
        }
      }
    },

    "catch": function(tryLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc === tryLoc) {
          var record = entry.completion;
          if (record.type === "throw") {
            var thrown = record.arg;
            resetTryEntry(entry);
          }
          return thrown;
        }
      }

      // The context.catch method must only be called with a location
      // argument that corresponds to a known catch block.
      throw new Error("illegal catch attempt");
    },

    delegateYield: function(iterable, resultName, nextLoc) {
      this.delegate = {
        iterator: values(iterable),
        resultName: resultName,
        nextLoc: nextLoc
      };

      return ContinueSentinel;
    }
  };
})(
  // Among the various tricks for obtaining a reference to the global
  // object, this seems to be the most reliable technique that does not
  // use indirect eval (which violates Content Security Policy).
  typeof global === "object" ? global :
  typeof window === "object" ? window :
  typeof self === "object" ? self : this
);
//# sourceURL=config.js
(function() {
    $('.right-aligned').append('<span id="runEditTest" class="glyphicons refresh" data-i18n="[title]controlbar.download"></span>');
    // need to increase min width of control bar to prevent bar from being pushed down.
    $('#control').css("min-width", 720);
    var editButton = $("#runEditTest");
    editButton.addClass("ui-state-disabled"); // initially disabled

    $(document).on('documentLoaded', function() {
        PDFNet.initialize().then(function(){
            var doc = readerControl.docViewer.getDocument();
            doc.getPDFDoc().then(function(pdfDoc){

                 // remove any past instances once a new document is loaded
                editButton.removeClass("ui-state-disabled");
                editButton.off("click");
                
                editButton.click(function() {
                    if(!editButton.hasClass("ui-state-disabled")){
                        editButton.addClass("ui-state-disabled");

                        runElementEditTest(pdfDoc).then(function(){
                            // re-enable our button
                            editButton.removeClass("ui-state-disabled");
                            // refresh the cache with the newly updated document
                            readerControl.docViewer.refreshAll();
                            // update viewer with new document
                            readerControl.docViewer.updateView();
                        });
                    }
                });
            });
        });
    });

    var runElementEditTest = function(pdfDoc)
    {
        var marked2$0 = [ProcessElements, main].map(regeneratorRuntime.mark);
        function ProcessElements(reader, writer, visited) {
            var element, colorspace, redColor, blueColor, elementType, gs, form_obj, form_obj_num, insertedObj, new_writer;

            return regeneratorRuntime.wrap(function ProcessElements$(context$3$0) {
                while (1) switch (context$3$0.prev = context$3$0.next) {
                case 0:
                    context$3$0.next = 2;
                    return PDFNet.startDeallocateStack();
                case 2:
                    console.log("Processing elements");
                    context$3$0.next = 5;
                    return PDFNet.ColorSpace.createDeviceRGB();
                case 5:
                    colorspace = context$3$0.sent;
                    context$3$0.next = 8;
                    return PDFNet.ColorPt.init(1, 0, 0, 0);
                case 8:
                    redColor = context$3$0.sent;
                    context$3$0.next = 11;
                    return PDFNet.ColorPt.init(0, 0, 1, 0);
                case 11:
                    blueColor = context$3$0.sent;
                    context$3$0.next = 14;
                    return reader.next();
                case 14:
                    element = context$3$0.sent;
                case 15:
                    if (!(element !== null)) {
                        context$3$0.next = 67;
                        break;
                    }

                    context$3$0.next = 18;
                    return element.getType();
                case 18:
                    elementType = context$3$0.sent;
                    context$3$0.t0 = elementType;
                    context$3$0.next = (context$3$0.t0 === PDFNet.Element.Type.e_image ? 22 : (context$3$0.t0 === PDFNet.Element.Type.e_inline_image ? 22 : (context$3$0.t0 === PDFNet.Element.Type.e_path ? 23 : (context$3$0.t0 === PDFNet.Element.Type.e_text ? 31 : (context$3$0.t0 === PDFNet.Element.Type.e_form ? 39 : 60)))));
                    break;
                case 22:
                    return context$3$0.abrupt("break", 62);
                case 23:
                    context$3$0.next = 25;
                    return element.getGState();
                case 25:
                    gs = context$3$0.sent;
                    gs.setFillColorSpace(colorspace);
                    gs.setFillColorWithColorPt(redColor);
                    context$3$0.next = 30;
                    return writer.writeElement(element);
                case 30:
                    return context$3$0.abrupt("break", 62);
                case 31:
                    context$3$0.next = 33;
                    return element.getGState();
                case 33:
                    gs = context$3$0.sent;
                    gs.setFillColorSpace(colorspace);
                    gs.setFillColorWithColorPt(blueColor);
                    context$3$0.next = 38;
                    return writer.writeElement(element);
                case 38:
                    return context$3$0.abrupt("break", 62);
                case 39:
                    context$3$0.next = 41;
                    return writer.writeElement(element);
                case 41:
                    context$3$0.next = 43;
                    return element.getXObject();
                case 43:
                    form_obj = context$3$0.sent;
                    form_obj_num = form_obj.getObjNum();

                    if (!// if XObject not yet processed
                    (visited.indexOf(form_obj_num) == -1)) {
                        context$3$0.next = 59;
                        break;
                    }

                    context$3$0.next = 48;
                    return form_obj.getObjNum();
                case 48:
                    insertedObj = context$3$0.sent;
                    if(_.findWhere(visited, insertedObj) == null) {
                        visited.push(insertedObj);
                    }
                    context$3$0.next = 52;
                    return PDFNet.ElementWriter.create();
                case 52:
                    new_writer = context$3$0.sent;
                    reader.formBegin();
                    new_writer.beginOnObj(form_obj, true);
                    return context$3$0.delegateYield(ProcessElements(reader, new_writer, visited), "t1", 56);
                case 56:
                    new_writer.end();
                    reader.end();
                    if(new_writer){
                        new_writer.destroy();
                    }
                case 59:
                    return context$3$0.abrupt("break", 62);
                case 60:
                    context$3$0.next = 62;
                    return writer.writeElement(element);
                case 62:
                    context$3$0.next = 64;
                    return reader.next();
                case 64:
                    element = context$3$0.sent;
                    context$3$0.next = 15;
                    break;
                case 67:
                    context$3$0.next = 69;
                    return PDFNet.endDeallocateStack();
                case 69:
                case "end":
                    return context$3$0.stop();
                }
            }, marked2$0[0], this);
        }

        function main() {
            var ret, islocked, doc, writer, reader, visited, pageCount, pageCounter, page, sdfObj, insertedObj;

            return regeneratorRuntime.wrap(function main$(context$3$0) {
                while (1) switch (context$3$0.prev = context$3$0.next) {
                case 0:
                    ret = 0;
                    context$3$0.prev = 1;
                    islocked = false;
                    doc = pdfDoc;
                    doc.lock();
                    islocked = true;
                    doc.initSecurityHandler();

                    context$3$0.next = 9;
                    return PDFNet.ElementWriter.create();
                case 9:
                    writer = context$3$0.sent;
                    context$3$0.next = 12;
                    return PDFNet.ElementReader.create();
                case 12:
                    reader = context$3$0.sent;
                    visited = [];
                    context$3$0.next = 16;
                    return doc.getPageCount();
                case 16:
                    pageCount = context$3$0.sent;
                    pageCounter = 1;
                case 18:
                    if (!(pageCounter <= pageCount)) {
                        context$3$0.next = 46;
                        break;
                    }

                    // This section is only required to ensure the page is available
                    // for incremental download. At the moment the call to requirePage must be
                    // be wrapped in this manner to avoid potential deadlocks and
                    // allow other parts of the viewer to run while the page is being downloaded.
                    doc.unlock();
                    context$3$0.next = 22;
                    return PDFNet.finishOperation();
                case 22:
                    context$3$0.next = 24;
                    return doc.requirePage(pageCounter);
                case 24:
                    context$3$0.next = 26;
                    return PDFNet.beginOperation();
                case 26:
                    doc.lock();

                    context$3$0.next = 29;
                    return doc.getPage(pageCounter);
                case 29:
                    page = context$3$0.sent;
                    context$3$0.next = 32;
                    return page.getSDFObj();
                case 32:
                    sdfObj = context$3$0.sent;
                    context$3$0.next = 35;
                    return sdfObj.getObjNum();
                case 35:
                    insertedObj = context$3$0.sent;
                    if(_.findWhere(visited, insertedObj) == null) {
                        visited.push(insertedObj);
                    }
                    reader.beginOnPage(page);
                    writer.beginOnPage(page, PDFNet.ElementWriter.WriteMode.e_replacement, false);
                    return context$3$0.delegateYield(ProcessElements(reader, writer, visited), "t0", 40);
                case 40:
                    writer.end();
                    reader.end();
                    console.log("page " + pageCounter + " finished editing");
                    pageCounter++;
                    context$3$0.next = 18;
                    break;
                case 46:
                    console.log("Done.");
                    context$3$0.next = 53;
                    break;
                case 49:
                    context$3$0.prev = 49;
                    context$3$0.t1 = context$3$0["catch"](1);
                    console.log(context$3$0.t1.stack)
                    ret = 1;
                case 53:
                    return context$3$0.abrupt("return", ret);
                case 54:
                case "end":
                    return context$3$0.stop();
                }
            }, marked2$0[1], this, [[1, 49]]);
        }

        return PDFNet.runGeneratorWithCleanup(main());
    }
})();